@@ -104,6 +104,8 @@ class EnsemblingSignalRunner(AbstractRunner):
             print('time range after filtering ')
             print(max(hourly_df.index))
             print(min(hourly_df.index))
+            close_df = hourly_df.copy()
+
             ## idiosyncratic run itself
             run_json_string = signal_utility.recover_to_sql_column_format(me_signal)
             params = json.loads(run_json_string)
@@ -137,10 +139,9 @@ class EnsemblingSignalRunner(AbstractRunner):
                 hourlysig_df.columns = ['signal']
                 hourly_df = hourlyperf_df.merge(hourlysig_df, left_index = True, right_index = True)
                 if cumulated_signals is None :
-                    hourlyclose_df = hourly_df['close'].to_frame()
+                    hourlyclose_df = close_df['close'].to_frame()
                     hourlyclose_df.columns = ['close']
                     hourly_df = hourly_df.merge(hourlyclose_df, left_index=True, right_index=True)
-
             if cumulated_signals is None:
                 if self.add_turn_over:
                     cumulated_signals = hourly_df[['close','signal','turn_over']]
